component accessors="true" extends="coldbox.system.Interceptor" {

    property name="multilingualPresideObjectService" inject="delayedInjector:multilingualPresideObjectService";

    public void function configure() {}

    public void function onRestRequest( event, interceptData ) {

        var restRequest = arguments.interceptData.restRequest;
        var restResponse = arguments.interceptData.restResponse;

        var httpRequestData = getHTTPRequestData();
        var headers = httpRequestData.headers;

        var languageCode = findLanguageCodeHeader(headers, "Accept-Language");

        if (!isValidLanguageCode(languageCode)) {
            languageCode = findLanguageCodeHeader(headers, "X-LANGUAGE");
        }

        if (!isValidLanguageCode(languageCode)) {
            languageCode = getDefaultLanguageCode();            
        }

        // TODO: maybe return an error in case of an invalid/illegal supplied language code?

        event.setLanguage(getLanguageID(languageCode));
    }

    private string function findLanguageCodeHeader(required struct headers, required string key) {

        if (!arguments.headers.keyExists(arguments.key)) {
            return "";
        }

        // deal with formats like 'en-gb', 'fr-FR', etc.
        if (listLen(arguments.headers[arguments.key], "-") gt 1) {
            return listFirst(arguments.headers[arguments.key], "-");
        }

        return arguments.headers[arguments.key];
    }

    private boolean function isValidLanguageCode(required string lang) {
        
        if (len(arguments.lang) eq 0) {
            return false;
        }

        return structKeyExists(getLanguageMap(), arguments.lang);
    }

    private struct function getLanguageMap() {
        if (!structKeyExists(variables, "languageIDs")) {
            var languageObjects = multilingualPresideObjectService.listLanguages();
            variables.languageIDs = {};
            for (var languageObject in languageObjects) {
                variables.languageIDs[languageObject.iso_code] = languageObject.id;
                if (languageObject.default) {
                    variables.defaultLanguageCode = languageObject.iso_code;
                }
            }
        }
        return variables.languageIDs;
    }

    private string function getLanguageID(required string lang) {
        return getLanguageMap()[arguments.lang];
    }

    private string function getDefaultLanguageCode() {
        // ensure language map is loaded
        getLanguageMap();
        return variables.defaultLanguageCode;
    }
}